@@ -151,6 +151,8 @@ class Sale(IdentifierMixin, metaclass=PoolMeta):
         Currency = pool.get('currency.currency')
         invoice = super().create_invoice()
         if invoice and self.shopify_tax_adjustment:
+            invoice.save()
+            invoice.update_taxes()
             adjustment = Currency.compute(
                 self.currency, self.shopify_tax_adjustment, invoice.currency,
                 round=False)
@@ -159,7 +161,8 @@ class Sale(IdentifierMixin, metaclass=PoolMeta):
                 round=False)
             remaining = invoice.currency.round(
                 adjustment * (invoice.untaxed_amount / untaxed_amount))
-            for tax in invoice.taxes:
+            taxes = invoice.taxes
+            for tax in taxes:
                 if tax.amount:
                     if invoice.tax_amount:
                         ratio = tax.amount / invoice.tax_amount
@@ -169,12 +172,13 @@ class Sale(IdentifierMixin, metaclass=PoolMeta):
                     tax.amount += value
                     remaining -= value
             if remaining:
-                for tax in invoice.taxes:
+                for tax in taxes:
                     if tax.amount:
                         tax.amount += remaining
                         break
-            invoice.taxes = invoice.taxes
+            invoice.taxes = taxes
             invoice.save()
+            invoice.update_taxes()
         return invoice
 
     @classmethod
